==> Gbook-1.0.tar.gz: Gbook/method.uninstall.php <==
<?php
#-------------------------------------------------------------------------
# Module: Gbook
# Author: Jos (josvd@live.nl)
# Method: Uninstall
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2008 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/gbook/
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

$db = cmsms()->GetDB();

// remove the database tables
$dict = NewDataDictionary( $db );
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_gbook_b8_wordlist" );
$dict->ExecuteSQLArray($sqlarray);

$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_gbook_smileys" );
$dict->ExecuteSQLArray($sqlarray);

$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_gbook_entries" );
$dict->ExecuteSQLArray($sqlarray);

$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_gbook" );
$dict->ExecuteSQLArray($sqlarray);


// remove the permissions
$this->RemovePermission('Gbook: Use');
$this->RemovePermission('Gbook: Modify');

// remove all templates
$this->DeleteTemplate();

global $CMS_VERSION;
if ( $CMS_VERSION >= '1.11' )
{
	// remove stylesheet
	$stylesheetops = cmsms()->GetStylesheetOperations();
	$stylesheetops->DeleteStylesheetByName('Gbook module');
}

// remove all preferences
$this->RemovePreference();

// remove the events
$this->RemoveEvent('Gbook_entry_added');
$this->RemoveEvent('Gbook_entry_edited');


if ( $CMS_VERSION >= '1.11' )
{
	$this->RemoveSmartyPlugin();

	cms_route_manager::del_static('',$this->GetName());
}

?>

==> Gbook-2.0.3.tar.gz: Gbook/method.uninstall.php <==
<?php
#-------------------------------------------------------------------------
# Module: Gbook
# Author: Jos (josvd@live.nl)
# Method: Uninstall
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2008 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/gbook/
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

$db = cmsms()->GetDB();

// remove the database tables
$dict = NewDataDictionary( $db );
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_gbook_b8_wordlist" );
$dict->ExecuteSQLArray($sqlarray);

$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_gbook_smileys" );
$dict->ExecuteSQLArray($sqlarray);

$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_gbook_entries" );
$dict->ExecuteSQLArray($sqlarray);

$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_gbook" );
$dict->ExecuteSQLArray($sqlarray);


// remove the permissions
$this->RemovePermission('Gbook: Use');
$this->RemovePermission('Gbook: Modify');

// remove all templates
$this->DeleteTemplate();

// remove stylesheet
if (version_compare(CMS_VERSION, '1.99-alpha0', '<'))
{
    $stylesheetops = cmsms()->GetStylesheetOperations();
    $stylesheetops->DeleteStylesheetByName('Gbook module');
}
else
{
    $css_ob = CmsLayoutStylesheet::load('Gbook module');
    $css_ob->delete();
}

// remove all preferences
$this->RemovePreference();

// remove the events
$this->RemoveEvent('Gbook_entry_added');
$this->RemoveEvent('Gbook_entry_edited');


$this->RemoveSmartyPlugin();

cms_route_manager::del_static('',$this->GetName());

?>
